@@ -337,7 +337,7 @@ function *(a::T, b::AbsPowerSeriesRingElem{T}) where {T <: RingElem}
    return z
 end
 
-function *(a::Union{Integer, Rational, AbstractFloat}, b::AbsPowerSeriesRingElem)
+function *(a::JuliaRingElement, b::AbsPowerSeriesRingElem)
    len = length(b)
    z = parent(b)()
    fit!(z, len)
@@ -351,7 +351,7 @@ end
 
 *(a::AbsPowerSeriesRingElem{T}, b::T) where {T <: RingElem} = b*a
 
-*(a::AbsPowerSeriesRingElem, b::Union{Integer, Rational, AbstractFloat}) = b*a
+*(a::AbsPowerSeriesRingElem, b::JuliaRingElement) = b*a
 
 ###############################################################################
 #
@@ -563,35 +563,21 @@ end
 ###############################################################################
 
 @doc raw"""
-    ==(x::AbsPowerSeriesRingElem{T}, y::T) where {T <: RingElem}
+    ==(x::AbsPowerSeriesRingElem{<:RingElem}, y::RingElement)
+    ==(x::RingElement, y::AbsPowerSeriesRingElem{<:RingElem})
 
 Return `true` if $x == y$ arithmetically, otherwise return `false`.
 """
 ==(x::AbsPowerSeriesRingElem{T}, y::T) where {T <: RingElem} = precision(x) == 0 ||
       ((length(x) == 0 && iszero(y)) || (length(x) == 1 && coeff(x, 0) == y))
 
-@doc raw"""
-    ==(x::T, y::AbsPowerSeriesRingElem{T}) where {T <: RingElem}
-
-Return `true` if $x == y$ arithmetically, otherwise return `false`.
-"""
 ==(x::T, y::AbsPowerSeriesRingElem{T}) where {T <: RingElem} = y == x
 
-@doc raw"""
-    ==(x::AbsPowerSeriesRingElem, y::Union{Integer, Rational, AbstractFloat})
-
-Return `true` if $x == y$ arithmetically, otherwise return `false`.
-"""
-==(x::AbsPowerSeriesRingElem, y::Union{Integer, Rational, AbstractFloat}) = precision(x) == 0 ||
+==(x::AbsPowerSeriesRingElem, y::JuliaRingElement) = precision(x) == 0 ||
                      ((length(x) == 0 && iszero(base_ring(x)(y))) ||
                       (length(x) == 1 && coeff(x, 0) == y))
 
-@doc raw"""
-    ==(x::Union{Integer, Rational, AbstractFloat}, y::AbsPowerSeriesRingElem)
-
-Return `true` if $x == y$ arithmetically, otherwise return `false`.
-"""
-==(x::Union{Integer, Rational, AbstractFloat}, y::AbsPowerSeriesRingElem) = y == x
+==(x::JuliaRingElement, y::AbsPowerSeriesRingElem) = y == x
 
 ###############################################################################
 #
@@ -654,7 +640,7 @@ end
 #
 ###############################################################################
 
-function divexact(x::AbsPowerSeriesRingElem, y::Union{Integer, Rational, AbstractFloat}; check::Bool=true)
+function divexact(x::AbsPowerSeriesRingElem, y::JuliaRingElement; check::Bool=true)
    iszero(y) && throw(DivideError())
    lenx = length(x)
    z = parent(x)()
@@ -905,13 +891,6 @@ function sqrt_classical(a::AbsPowerSeriesRingElem; check::Bool=true)
    return true, asqrt
 end
 
-@doc raw"""
-    sqrt(a::AbsPowerSeriesRingElem; check::Bool=true)
-
-Return the square root of the power series $a$. By default the function will
-throw an exception if the input is not square. If `check=false` this test is
-omitted.
-"""
 function Base.sqrt(a::AbsPowerSeriesRingElem; check::Bool=true)
    flag, q = sqrt_classical(a; check=check)
    if check && !flag
