@@ -177,12 +177,12 @@ end
 
 
 @doc raw"""
-    is_square(a::T)  where {T <: NCRingElement}
+    is_square(a::NCRingElement)
 
 Return `true` iff `a` is the square of a value in its own ring.
 See also `is_square(M::MatElem)` which tests whether a matrix has square shape.
 """
-function is_square end
+is_square(::NCRingElement)
 
 @doc raw"""
     sqrt(a::NCRingElem; check::Bool=true)
