@@ -17,8 +17,8 @@
 # algos differ, and 7 can often stand in for 5/6 if the algorithm supports it.
 
 @testset "Generic.Poly.types" begin
-   @test dense_poly_type(BigInt) == Generic.Poly{BigInt}
-   @test dense_poly_type(Rational{BigInt}) == Generic.Poly{Rational{BigInt}}
+   @test poly_type(BigInt) == Generic.Poly{BigInt}
+   @test poly_type(Rational{BigInt}) == Generic.Poly{Rational{BigInt}}
 end
 
 @testset "Generic.Poly.constructors" begin
